from box.collections import Settings
from .version import version


class Settings(Settings):

    # Main

    # TODO: remove default word?
    default_command = 'run bootstrap'
    default_pattern = 'default'

    # Argparse

    @property
    def argparse(self):
        return {
            'prog': 'packgram',
            'add_help': False,
            'arguments': [
                {
                 'name': 'path',
                 'help': 'Path to create packgram.',
                },
                {
                 'dest': 'command',
                 'flags': ['-c', '--command'],
                 'default': self.default_command,
                 'help': 'Command to bootstrap packgram.',
                },
                {
                 'dest': 'debug',
                 'action': 'store_true',
                 'flags': ['-d', '--debug'],
                 'help': 'Enable debug mode.',
                },
                {
                 'action': 'help',
                 'flags': ['-h', '--help'],
                 'help': 'Display this help message.',
                },
                {
                 'dest': 'pattern',
                 'flags': ['-p', '--pattern'],
                 'default': self.default_pattern,
                 'help': 'Pattern to create packgram.',
                },
                {
                 'dest': 'quiet',
                 'action': 'store_true',
                 'flags': ['-q', '--quiet'],
                 'help': 'Enable quiet mode.',
                },
                {
                 'dest': 'verbose',
                 'action': 'store_true',
                 'flags': ['-v', '--verbose'],
                 'help': 'Enable verbose mode.',
                },
                {
                 'action': 'version',
                 'flags': ['-V', '--version'],
                 'version': 'Packgram ' + str(version),
                 'help': 'Display the program version.',
                },
            ]
        }

    # Logging

    logging_level = 'WARNING'
    logging_format = '[%(levelname)s] %(message)s'

    @property
    def logging(self):
        return {
            'version': 1,
            'disable_existing_loggers': False,
            'loggers': {
                '': {
                    'handlers': ['default'],
                    'level': self.logging_level,
                    'propagate': True,
                },
            },
            'handlers': {
                'default': {
                    'level': 'DEBUG',
                    'class': 'logging.StreamHandler',
                    'formatter': 'default',
                },
            },
            'formatters': {
                'default': {
                    'format': self.logging_format
                },
            },
        }


settings = Settings()
